@@ -1,11 +1,13 @@
 //! Value types accepted by leaf query clauses
 
 mod geo_point;
+mod number;
 mod scalar;
 mod search;
 mod units;
 
 pub use self::geo_point::*;
+pub use self::number::*;
 pub use self::scalar::*;
 pub use self::search::*;
 pub use self::units::*;
